Class: Google::Cloud::PrivilegedAccessManager::V1::CheckOnboardingStatusResponse::Finding

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb

Overview

Finding represents an issue which prevents PAM from functioning properly for this resource.

Defined Under Namespace

Classes: IAMAccessDenied

Instance Attribute Summary collapse

Instance Attribute Details

#iam_access_denied::Google::Cloud::PrivilegedAccessManager::V1::CheckOnboardingStatusResponse::Finding::IAMAccessDenied

Returns PAM's service account is being denied access by Cloud IAM.

Returns:



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 56

class Finding
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # PAM's service account is being denied access by Cloud IAM.
  # This can be fixed by granting a role that contains the missing
  # permissions to the service account or exempting it from deny policies if
  # they are blocking the access.
  # @!attribute [rw] missing_permissions
  #   @return [::Array<::String>]
  #     List of permissions that are being denied.
  class IAMAccessDenied
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end