Class: Google::Cloud::PrivilegedAccessManager::V1::CreateGrantRequest
- Inherits:
-
Object
- Object
- Google::Cloud::PrivilegedAccessManager::V1::CreateGrantRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb
Overview
Message for creating a grant
Instance Attribute Summary collapse
-
#grant ⇒ ::Google::Cloud::PrivilegedAccessManager::V1::Grant
Required.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#grant ⇒ ::Google::Cloud::PrivilegedAccessManager::V1::Grant
Returns Required. The resource being created.
966 967 968 969 |
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 966 class CreateGrantRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. Name of the parent entitlement for which this grant is being requested.
966 967 968 969 |
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 966 class CreateGrantRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server knows to ignore the request if it has already been completed. The server guarantees this for at least 60 minutes after the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, ignores the second request. This prevents clients from accidentally creating duplicate grants.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
966 967 968 969 |
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 966 class CreateGrantRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |