Class: Google::Cloud::PrivilegedAccessManager::V1::DenyGrantRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb

Overview

Request message for DenyGrant method.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. Name of the grant resource which is being denied.

Returns:

  • (::String)

    Required. Name of the grant resource which is being denied.



926
927
928
929
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 926

class DenyGrantRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#reason::String

Returns Optional. The reason for denying this grant. This is required if require_approver_justification field of the ManualApprovals workflow used in this grant is true.

Returns:

  • (::String)

    Optional. The reason for denying this grant. This is required if require_approver_justification field of the ManualApprovals workflow used in this grant is true.



926
927
928
929
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 926

class DenyGrantRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end