Class: Google::Cloud::PrivilegedAccessManager::V1::Entitlement::AdditionalNotificationTargets

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb

Overview

AdditionalNotificationTargets includes email addresses to be notified.

Instance Attribute Summary collapse

Instance Attribute Details

#admin_email_recipients::Array<::String>

Returns Optional. Additional email addresses to be notified when a principal (requester) is granted access.

Returns:

  • (::Array<::String>)

    Optional. Additional email addresses to be notified when a principal (requester) is granted access.



170
171
172
173
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 170

class AdditionalNotificationTargets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#requester_email_recipients::Array<::String>

Returns Optional. Additional email address to be notified about an eligible entitlement.

Returns:

  • (::Array<::String>)

    Optional. Additional email address to be notified about an eligible entitlement.



170
171
172
173
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 170

class AdditionalNotificationTargets
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end