Class: Google::Cloud::PrivilegedAccessManager::V1::Entitlement::RequesterJustificationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb

Overview

Defines how a requester must provide a justification when requesting access.

Defined Under Namespace

Classes: NotMandatory, Unstructured

Instance Attribute Summary collapse

Instance Attribute Details

#not_mandatory::Google::Cloud::PrivilegedAccessManager::V1::Entitlement::RequesterJustificationConfig::NotMandatory

Returns This option means the requester isn't required to provide a justification.

Note: The following fields are mutually exclusive: not_mandatory, unstructured. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 143

class RequesterJustificationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The justification is not mandatory but can be provided in any of the
  # supported formats.
  class NotMandatory
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The requester has to provide a justification in the form of a string.
  class Unstructured
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#unstructured::Google::Cloud::PrivilegedAccessManager::V1::Entitlement::RequesterJustificationConfig::Unstructured

Returns This option means the requester must provide a string as justification. If this is selected, the server allows the requester to provide a justification but doesn't validate it.

Note: The following fields are mutually exclusive: unstructured, not_mandatory. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 143

class RequesterJustificationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The justification is not mandatory but can be provided in any of the
  # supported formats.
  class NotMandatory
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The requester has to provide a justification in the form of a string.
  class Unstructured
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end