Module: Google::Cloud::PrivilegedAccessManager::V1::Grant::State

Defined in:
proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb

Overview

Different states a grant can be in.

Constant Summary collapse

STATE_UNSPECIFIED =

Unspecified state. This value is never returned by the server.

0
APPROVAL_AWAITED =

The entitlement had an approval workflow configured and this grant is waiting for the workflow to complete.

1
DENIED =

The approval workflow completed with a denied result. No access is granted for this grant. This is a terminal state.

3
SCHEDULED =

The approval workflow completed successfully with an approved result or none was configured. Access is provided at an appropriate time.

4
ACTIVATING =

Access is being given.

5
ACTIVE =

Access was successfully given and is currently active.

6
ACTIVATION_FAILED =

The system could not give access due to a non-retriable error. This is a terminal state.

7
EXPIRED =

Expired after waiting for the approval workflow to complete. This is a terminal state.

8
REVOKING =

Access is being revoked.

9
REVOKED =

Access was revoked by a user. This is a terminal state.

10
ENDED =

System took back access as the requested duration was over. This is a terminal state.

11
WITHDRAWING =

Access is being withdrawn.

12
WITHDRAWN =

Grant was withdrawn by the grant owner. This is a terminal state.

13