Class: Google::Cloud::PrivilegedAccessManager::V1::ListGrantsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb

Overview

Message for requesting list of grants.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filtering results.

Returns:

  • (::String)

    Optional. Filtering results.



823
824
825
826
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 823

class ListGrantsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Hint for how to order the results.

Returns:

  • (::String)

    Optional. Hint for how to order the results



823
824
825
826
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 823

class ListGrantsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Requested page size. The server may return fewer items than requested. If unspecified, the server picks an appropriate default.

Returns:

  • (::Integer)

    Optional. Requested page size. The server may return fewer items than requested. If unspecified, the server picks an appropriate default.



823
824
825
826
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 823

class ListGrantsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A token identifying a page of results the server should return.

Returns:

  • (::String)

    Optional. A token identifying a page of results the server should return.



823
824
825
826
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 823

class ListGrantsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource which owns the grants.

Returns:

  • (::String)

    Required. The parent resource which owns the grants.



823
824
825
826
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 823

class ListGrantsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end