Class: Google::Cloud::PrivilegedAccessManager::V1::ListGrantsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::PrivilegedAccessManager::V1::ListGrantsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb
Overview
Message for response to listing grants.
Instance Attribute Summary collapse
-
#grants ⇒ ::Array<::Google::Cloud::PrivilegedAccessManager::V1::Grant>
The list of grants.
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
-
#unreachable ⇒ ::Array<::String>
Locations that could not be reached.
Instance Attribute Details
#grants ⇒ ::Array<::Google::Cloud::PrivilegedAccessManager::V1::Grant>
Returns The list of grants.
838 839 840 841 |
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 838 class ListGrantsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
838 839 840 841 |
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 838 class ListGrantsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Locations that could not be reached.
838 839 840 841 |
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 838 class ListGrantsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |