Class: Google::Cloud::PrivilegedAccessManager::V1::ManualApprovals::Step

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb

Overview

Step represents a logical step in a manual approval workflow.

Instance Attribute Summary collapse

Instance Attribute Details

#approvals_needed::Integer

Returns Required. How many users from the above list need to approve. If there aren't enough distinct users in the list, then the workflow indefinitely blocks. Should always be greater than 0. 1 is the only supported value.

Returns:

  • (::Integer)

    Required. How many users from the above list need to approve. If there aren't enough distinct users in the list, then the workflow indefinitely blocks. Should always be greater than 0. 1 is the only supported value.



260
261
262
263
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 260

class Step
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#approver_email_recipients::Array<::String>

Returns Optional. Additional email addresses to be notified when a grant is pending approval.

Returns:

  • (::Array<::String>)

    Optional. Additional email addresses to be notified when a grant is pending approval.



260
261
262
263
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 260

class Step
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#approvers::Array<::Google::Cloud::PrivilegedAccessManager::V1::AccessControlEntry>

Returns Optional. The potential set of approvers in this step. This list must contain at most one entry.

Returns:



260
261
262
263
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 260

class Step
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end