Class: Google::Cloud::PrivilegedAccessManager::V1::PrivilegedAccess::GcpIamAccess

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb

Overview

GcpIamAccess represents IAM based access control on a Google Cloud resource. Refer to https://cloud.google.com/iam/docs to understand more about IAM.

Defined Under Namespace

Classes: RoleBinding

Instance Attribute Summary collapse

Instance Attribute Details

#resource::String

Returns Required. Name of the resource.

Returns:

  • (::String)

    Required. Name of the resource.



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 286

class GcpIamAccess
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # IAM role bindings that are created after a successful grant.
  # @!attribute [rw] role
  #   @return [::String]
  #     Required. IAM role to be granted.
  #     https://cloud.google.com/iam/docs/roles-overview.
  # @!attribute [rw] condition_expression
  #   @return [::String]
  #     Optional. The expression field of the IAM condition to be associated
  #     with the role. If specified, a user with an active grant for this
  #     entitlement is able to access the resource only if this condition
  #     evaluates to true for their request.
  #
  #     This field uses the same CEL format as IAM and supports all attributes
  #     that IAM supports, except tags.
  #     https://cloud.google.com/iam/docs/conditions-overview#attributes.
  class RoleBinding
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#resource_type::String

Returns Required. The type of this resource.

Returns:

  • (::String)

    Required. The type of this resource.



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 286

class GcpIamAccess
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # IAM role bindings that are created after a successful grant.
  # @!attribute [rw] role
  #   @return [::String]
  #     Required. IAM role to be granted.
  #     https://cloud.google.com/iam/docs/roles-overview.
  # @!attribute [rw] condition_expression
  #   @return [::String]
  #     Optional. The expression field of the IAM condition to be associated
  #     with the role. If specified, a user with an active grant for this
  #     entitlement is able to access the resource only if this condition
  #     evaluates to true for their request.
  #
  #     This field uses the same CEL format as IAM and supports all attributes
  #     that IAM supports, except tags.
  #     https://cloud.google.com/iam/docs/conditions-overview#attributes.
  class RoleBinding
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#role_bindings::Array<::Google::Cloud::PrivilegedAccessManager::V1::PrivilegedAccess::GcpIamAccess::RoleBinding>

Returns Required. Role bindings that are created on successful grant.

Returns:



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 286

class GcpIamAccess
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # IAM role bindings that are created after a successful grant.
  # @!attribute [rw] role
  #   @return [::String]
  #     Required. IAM role to be granted.
  #     https://cloud.google.com/iam/docs/roles-overview.
  # @!attribute [rw] condition_expression
  #   @return [::String]
  #     Optional. The expression field of the IAM condition to be associated
  #     with the role. If specified, a user with an active grant for this
  #     entitlement is able to access the resource only if this condition
  #     evaluates to true for their request.
  #
  #     This field uses the same CEL format as IAM and supports all attributes
  #     that IAM supports, except tags.
  #     https://cloud.google.com/iam/docs/conditions-overview#attributes.
  class RoleBinding
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end