Class: Google::Cloud::PrivilegedAccessManager::V1::RevokeGrantRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb

Overview

Request message for RevokeGrant method.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. Name of the grant resource which is being revoked.

Returns:

  • (::String)

    Required. Name of the grant resource which is being revoked.



938
939
940
941
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 938

class RevokeGrantRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#reason::String

Returns Optional. The reason for revoking this grant.

Returns:

  • (::String)

    Optional. The reason for revoking this grant.



938
939
940
941
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 938

class RevokeGrantRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end