Class: Google::Cloud::PrivilegedAccessManager::V1::SearchGrantsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb

Overview

Request message for SearchGrants method.

Defined Under Namespace

Modules: CallerRelationshipType

Instance Attribute Summary collapse

Instance Attribute Details

#caller_relationship::Google::Cloud::PrivilegedAccessManager::V1::SearchGrantsRequest::CallerRelationshipType

Returns Required. Only grants which the caller is related to by this relationship are returned in the response.

Returns:



861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 861

class SearchGrantsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Different types of relationships a user can have with a grant.
  module CallerRelationshipType
    # Unspecified caller relationship type.
    CALLER_RELATIONSHIP_TYPE_UNSPECIFIED = 0

    # The user created this grant by calling `CreateGrant` earlier.
    HAD_CREATED = 1

    # The user is an approver for the entitlement that this grant is parented
    # under and can currently approve/deny it.
    CAN_APPROVE = 2

    # The caller had successfully approved/denied this grant earlier.
    HAD_APPROVED = 3
  end
end

#filter::String

Returns Optional. Only grants matching this filter are returned in the response.

Returns:

  • (::String)

    Optional. Only grants matching this filter are returned in the response.



861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 861

class SearchGrantsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Different types of relationships a user can have with a grant.
  module CallerRelationshipType
    # Unspecified caller relationship type.
    CALLER_RELATIONSHIP_TYPE_UNSPECIFIED = 0

    # The user created this grant by calling `CreateGrant` earlier.
    HAD_CREATED = 1

    # The user is an approver for the entitlement that this grant is parented
    # under and can currently approve/deny it.
    CAN_APPROVE = 2

    # The caller had successfully approved/denied this grant earlier.
    HAD_APPROVED = 3
  end
end

#page_size::Integer

Returns Optional. Requested page size. The server may return fewer items than requested. If unspecified, server picks an appropriate default.

Returns:

  • (::Integer)

    Optional. Requested page size. The server may return fewer items than requested. If unspecified, server picks an appropriate default.



861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 861

class SearchGrantsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Different types of relationships a user can have with a grant.
  module CallerRelationshipType
    # Unspecified caller relationship type.
    CALLER_RELATIONSHIP_TYPE_UNSPECIFIED = 0

    # The user created this grant by calling `CreateGrant` earlier.
    HAD_CREATED = 1

    # The user is an approver for the entitlement that this grant is parented
    # under and can currently approve/deny it.
    CAN_APPROVE = 2

    # The caller had successfully approved/denied this grant earlier.
    HAD_APPROVED = 3
  end
end

#page_token::String

Returns Optional. A token identifying a page of results the server should return.

Returns:

  • (::String)

    Optional. A token identifying a page of results the server should return.



861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 861

class SearchGrantsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Different types of relationships a user can have with a grant.
  module CallerRelationshipType
    # Unspecified caller relationship type.
    CALLER_RELATIONSHIP_TYPE_UNSPECIFIED = 0

    # The user created this grant by calling `CreateGrant` earlier.
    HAD_CREATED = 1

    # The user is an approver for the entitlement that this grant is parented
    # under and can currently approve/deny it.
    CAN_APPROVE = 2

    # The caller had successfully approved/denied this grant earlier.
    HAD_APPROVED = 3
  end
end

#parent::String

Returns Required. The parent which owns the grant resources.

Returns:

  • (::String)

    Required. The parent which owns the grant resources.



861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 861

class SearchGrantsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Different types of relationships a user can have with a grant.
  module CallerRelationshipType
    # Unspecified caller relationship type.
    CALLER_RELATIONSHIP_TYPE_UNSPECIFIED = 0

    # The user created this grant by calling `CreateGrant` earlier.
    HAD_CREATED = 1

    # The user is an approver for the entitlement that this grant is parented
    # under and can currently approve/deny it.
    CAN_APPROVE = 2

    # The caller had successfully approved/denied this grant earlier.
    HAD_APPROVED = 3
  end
end