Class: Google::Cloud::PrivilegedAccessManager::V1::SearchGrantsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::PrivilegedAccessManager::V1::SearchGrantsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb
Overview
Response message for SearchGrants method.
Instance Attribute Summary collapse
-
#grants ⇒ ::Array<::Google::Cloud::PrivilegedAccessManager::V1::Grant>
The list of grants.
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
Instance Attribute Details
#grants ⇒ ::Array<::Google::Cloud::PrivilegedAccessManager::V1::Grant>
Returns The list of grants.
889 890 891 892 |
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 889 class SearchGrantsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
889 890 891 892 |
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 889 class SearchGrantsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |