Class: Google::Cloud::PrivilegedAccessManager::V1::Grant::Timeline
- Inherits:
-
Object
- Object
- Google::Cloud::PrivilegedAccessManager::V1::Grant::Timeline
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb
Overview
Timeline of a grant describing what happened to it and when.
Defined Under Namespace
Classes: Event
Instance Attribute Summary collapse
-
#events ⇒ ::Array<::Google::Cloud::PrivilegedAccessManager::V1::Grant::Timeline::Event>
readonly
Output only.
Instance Attribute Details
#events ⇒ ::Array<::Google::Cloud::PrivilegedAccessManager::V1::Grant::Timeline::Event> (readonly)
Returns Output only. The events that have occurred on this grant. This list
contains entries in the same order as they occurred. The first entry is
always be of type Requested and there is always at least one entry in
this array.
562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 |
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 562 class Timeline include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A single operation on the grant. # @!attribute [rw] requested # @return [::Google::Cloud::PrivilegedAccessManager::V1::Grant::Timeline::Event::Requested] # The grant was requested. # # Note: The following fields are mutually exclusive: `requested`, `approved`, `denied`, `revoked`, `scheduled`, `activated`, `activation_failed`, `expired`, `ended`, `externally_modified`, `withdrawn`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] approved # @return [::Google::Cloud::PrivilegedAccessManager::V1::Grant::Timeline::Event::Approved] # The grant was approved. # # Note: The following fields are mutually exclusive: `approved`, `requested`, `denied`, `revoked`, `scheduled`, `activated`, `activation_failed`, `expired`, `ended`, `externally_modified`, `withdrawn`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] denied # @return [::Google::Cloud::PrivilegedAccessManager::V1::Grant::Timeline::Event::Denied] # The grant was denied. # # Note: The following fields are mutually exclusive: `denied`, `requested`, `approved`, `revoked`, `scheduled`, `activated`, `activation_failed`, `expired`, `ended`, `externally_modified`, `withdrawn`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] revoked # @return [::Google::Cloud::PrivilegedAccessManager::V1::Grant::Timeline::Event::Revoked] # The grant was revoked. # # Note: The following fields are mutually exclusive: `revoked`, `requested`, `approved`, `denied`, `scheduled`, `activated`, `activation_failed`, `expired`, `ended`, `externally_modified`, `withdrawn`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] scheduled # @return [::Google::Cloud::PrivilegedAccessManager::V1::Grant::Timeline::Event::Scheduled] # The grant has been scheduled to give access. # # Note: The following fields are mutually exclusive: `scheduled`, `requested`, `approved`, `denied`, `revoked`, `activated`, `activation_failed`, `expired`, `ended`, `externally_modified`, `withdrawn`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] activated # @return [::Google::Cloud::PrivilegedAccessManager::V1::Grant::Timeline::Event::Activated] # The grant was successfully activated to give access. # # Note: The following fields are mutually exclusive: `activated`, `requested`, `approved`, `denied`, `revoked`, `scheduled`, `activation_failed`, `expired`, `ended`, `externally_modified`, `withdrawn`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] activation_failed # @return [::Google::Cloud::PrivilegedAccessManager::V1::Grant::Timeline::Event::ActivationFailed] # There was a non-retriable error while trying to give access. # # Note: The following fields are mutually exclusive: `activation_failed`, `requested`, `approved`, `denied`, `revoked`, `scheduled`, `activated`, `expired`, `ended`, `externally_modified`, `withdrawn`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] expired # @return [::Google::Cloud::PrivilegedAccessManager::V1::Grant::Timeline::Event::Expired] # The approval workflow did not complete in the necessary duration, # and so the grant is expired. # # Note: The following fields are mutually exclusive: `expired`, `requested`, `approved`, `denied`, `revoked`, `scheduled`, `activated`, `activation_failed`, `ended`, `externally_modified`, `withdrawn`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ended # @return [::Google::Cloud::PrivilegedAccessManager::V1::Grant::Timeline::Event::Ended] # Access given by the grant ended automatically as the approved # duration was over. # # Note: The following fields are mutually exclusive: `ended`, `requested`, `approved`, `denied`, `revoked`, `scheduled`, `activated`, `activation_failed`, `expired`, `externally_modified`, `withdrawn`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] externally_modified # @return [::Google::Cloud::PrivilegedAccessManager::V1::Grant::Timeline::Event::ExternallyModified] # The policy bindings made by grant have been modified outside of PAM. # # Note: The following fields are mutually exclusive: `externally_modified`, `requested`, `approved`, `denied`, `revoked`, `scheduled`, `activated`, `activation_failed`, `expired`, `ended`, `withdrawn`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] withdrawn # @return [::Google::Cloud::PrivilegedAccessManager::V1::Grant::Timeline::Event::Withdrawn] # The grant was withdrawn. # # Note: The following fields are mutually exclusive: `withdrawn`, `requested`, `approved`, `denied`, `revoked`, `scheduled`, `activated`, `activation_failed`, `expired`, `ended`, `externally_modified`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] event_time # @return [::Google::Protobuf::Timestamp] # Output only. The time (as recorded at server) when this event occurred. class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An event representing that a grant was requested. # @!attribute [r] expire_time # @return [::Google::Protobuf::Timestamp] # Output only. The time at which this grant expires unless the approval # workflow completes. If omitted, then the request never expires. class Requested include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An event representing that the grant was approved. # @!attribute [r] reason # @return [::String] # Output only. The reason provided by the approver for approving the # grant. # @!attribute [r] actor # @return [::String] # Output only. Username of the user who approved the grant. class Approved include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An event representing that the grant was denied. # @!attribute [r] reason # @return [::String] # Output only. The reason provided by the approver for denying the # grant. # @!attribute [r] actor # @return [::String] # Output only. Username of the user who denied the grant. class Denied include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An event representing that the grant was revoked. # @!attribute [r] reason # @return [::String] # Output only. The reason provided by the user for revoking the grant. # @!attribute [r] actor # @return [::String] # Output only. Username of the user who revoked the grant. class Revoked include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An event representing that the grant was withdrawn. class Withdrawn include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An event representing that the grant has been scheduled to be # activated later. # @!attribute [r] scheduled_activation_time # @return [::Google::Protobuf::Timestamp] # Output only. The time at which the access is granted. class Scheduled include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An event representing that the grant was successfully # activated. class Activated include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An event representing that the grant activation failed. # @!attribute [r] error # @return [::Google::Rpc::Status] # Output only. The error that occurred while activating the grant. class ActivationFailed include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An event representing that the grant was expired. class Expired include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An event representing that the grant has ended. class Ended include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An event representing that the policy bindings made by this grant were # modified externally. class ExternallyModified include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |