Class: Google::Cloud::PrivilegedAccessManager::V1::Justification
- Inherits:
-
Object
- Object
- Google::Cloud::PrivilegedAccessManager::V1::Justification
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb
Overview
Justification represents a justification for requesting access.
Instance Attribute Summary collapse
-
#unstructured_justification ⇒ ::String
A free form textual justification.
Instance Attribute Details
#unstructured_justification ⇒ ::String
Returns A free form textual justification. The system only ensures that this is not empty. No other kind of validation is performed on the string.
801 802 803 804 |
# File 'proto_docs/google/cloud/privilegedaccessmanager/v1/privilegedaccessmanager.rb', line 801 class Justification include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |